
Next Corpus Editor
==================

Factoring out the corpus format is a
first step in creating a revised editor.

Another major component of Selkie is a lightweight format for language
documentation and annotation, the Selkie Language Corpus (SLC) format,
along with functionality for creating, managing, and programmatically
accessing files in that format. The data representation is
intentionally defined separately from any particular application for
editing the data.

.. toctree::
   :titlesonly:

   corpus/index
   server/index
